package rag

import (
	"context"
	"github.com/mitchellh/mapstructure"
	ragApi "leafdev.top/leaf/rag/api/rag"
)

func (Service) ListLibrary(ctx context.Context, _ *ragApi.ListLibraryRequest) (*ragApi.ListLibraryResponse, error) {
	libraries, err := libraryLogic.ListLibrary(ctx)
	if err != nil {
		return nil, err
	}

	libraryResponse := &ragApi.ListLibraryResponse{}

	// convert
	for _, library := range libraries {
		var libraryResponseItem = ragApi.Library{
			Id:        int64(library.ID),
			Name:      library.Name,
			UserId:    library.UserID,
			CreatedAt: library.CreatedAt.String(),
			UpdatedAt: library.UpdatedAt.String(),
		}
		libraryResponse.Libraries = append(libraryResponse.Libraries, &libraryResponseItem)
	}

	return libraryResponse, err
}

func (Service) CreateLibrary(ctx context.Context, req *ragApi.CreateLibraryRequest) (*ragApi.CreateLibraryResponse, error) {
	library, err := libraryLogic.CreateLibrary(ctx, req.Name)
	if err != nil {
		return nil, err
	}

	var libraryApiResponse ragApi.CreateLibraryResponse
	err = mapstructure.Decode(library, &libraryApiResponse)
	if err != nil {
		return nil, err
	}

	return &libraryApiResponse, nil
}
